@@ -289,15 +289,15 @@ class BackgroundQueueWorker(BackgroundAsyncWorker):
 
     def put_threadsafe(self, t):
         if self._active or t is None:
-            asyncio.run_coroutine_threadsafe(self._Q.put(t),
-                                             loop=self.worker_loop).result()
+            return asyncio.run_coroutine_threadsafe(self._Q.put(t),
+                                                    loop=self.worker_loop)
 
     async def put(self, t):
         await self._Q.put(t)
 
     def send_stop_events(self):
         try:
-            self.put_threadsafe(None).result()
+            self.put_threadsafe(None)
         except:
             pass
 
@@ -342,7 +342,7 @@ class BackgroundEventWorker(BackgroundAsyncWorker):
 
     def trigger_threadsafe(self, force=False):
         if not self._current_task or force:
-            asyncio.run_coroutine_threadsafe(self._set_event(),
+            return asyncio.run_coroutine_threadsafe(self._set_event(),
                                              loop=self.worker_loop)
 
     async def trigger(self, force=False):
@@ -411,7 +411,7 @@ class BackgroundIntervalWorker(BackgroundAsyncWorker):
     def trigger_threadsafe(self, force=False, skip=False):
         if not self._current_task or force:
             self._skip = skip
-            asyncio.run_coroutine_threadsafe(self._cancel_sleep(),
+            return asyncio.run_coroutine_threadsafe(self._cancel_sleep(),
                                              loop=self.worker_loop)
 
     async def trigger(self, force=False, skip=False):
